package com.boman.web.core.service.vaccineInfo;

import com.boman.web.core.domain.VaccineInfoOperation;

import java.util.List;

/**
 * 疫苗信息Service接口
 * 
 * @author ruoyi
 * @date 2021-09-05
 */
public interface IVaccineInfoService 
{
    /**
     * 查询疫苗信息
     * 
     * @param id 疫苗信息ID
     * @return 疫苗信息
     */
    public VaccineInfoOperation selectVaccineInfoById(Long id);

    /**
     * 查询疫苗信息列表
     * 
     * @param vaccineInfo 疫苗信息
     * @return 疫苗信息集合
     */
    public List<VaccineInfoOperation> selectVaccineInfoList(VaccineInfoOperation vaccineInfo);

    /**
     * 新增疫苗信息
     * 
     * @param vaccineInfo 疫苗信息
     * @return 结果
     */
    public int insertVaccineInfo(VaccineInfoOperation vaccineInfo);

    /**
     * 修改疫苗信息
     * 
     * @param vaccineInfo 疫苗信息
     * @return 结果
     */
    public int updateVaccineInfo(VaccineInfoOperation vaccineInfo);

    /**
     * 批量删除疫苗信息
     * 
     * @param ids 需要删除的疫苗信息ID
     * @return 结果
     */
    public int deleteVaccineInfoByIds(Long[] ids);

    /**
     * 删除疫苗信息信息
     * 
     * @param id 疫苗信息ID
     * @return 结果
     */
    public int deleteVaccineInfoById(Long id);

    /**
     * 根据身份证查询信息
     * @param vaccineInfo
     * @return
     */
    public VaccineInfoOperation  findHjInfo(VaccineInfoOperation vaccineInfo);
}
